package com.yundian.flutter.alive.yundian_alive

import android.content.Context
import androidx.annotation.NonNull
import com.yundian.baseui.utils.AesUtils
import com.yundian.sdk.android.alive.ui.api.AliveDetectedResultListener
import com.yundian.sdk.android.alive.ui.api.AliveUiManager

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** YundianAlivePlugin */
class YundianAlivePlugin: FlutterPlugin, MethodCallHandler {
  private var channel: MethodChannel? = null
  private var resultListener: EventChannel? = null
  private lateinit var context: Context
  private var aliveEventSink: EventChannel.EventSink? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    context = flutterPluginBinding.applicationContext
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "yundian_alive")
    channel?.setMethodCallHandler(this)

    resultListener = EventChannel(flutterPluginBinding.binaryMessenger, "yundian_alive.event.alive.result_listener")
    resultListener?.setStreamHandler(object : EventChannel.StreamHandler {
      override fun onListen(p0: Any?, eventSink: EventChannel.EventSink?) {
        aliveEventSink = eventSink
      }

      override fun onCancel(p0: Any?) {
        aliveEventSink?.endOfStream()
      }
    })
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
      "getPlatformVersion" -> result.success(" alive Android ${android.os.Build.VERSION.RELEASE}")
      "alive_encrypt_aes" -> {
        var info = call.argument("info") as? String
        var appSecret = call.argument("appSecret") as? String
        result.success(AesUtils.encryptAes(info, appSecret))
      }
      "alive_init" -> {
        var isDebug = call.argument("isDebug") as? Boolean ?: false
        var appKey = call.argument("appKey") as? String
        var mchInfo = call.argument("mchInfo") as? String
        var riskInfo = call.argument("riskInfo") as? String
        AliveUiManager.getInstance().init(context, isDebug, appKey, mchInfo, riskInfo)
        result.success("alive_init success")
      }
      "alive_start_detect" -> {
        var hasResultPage = call.argument("hasResultPage") as? Boolean ?: false
        var authToken = call.argument("authToken") as? String
        var distance = call.argument("distance") as? Float ?: 3f
        AliveUiManager.getInstance().startActivity(context, authToken, distance, hasResultPage, object : AliveDetectedResultListener {
          override fun success(score: Double) {
            aliveEventSink?.success(AliveResult(0, "success", score).toResult())
          }

          override fun cancel(msg: String?) {
            aliveEventSink?.success(AliveResult(1, msg, 0.0).toResult())
          }

          override fun fail(msg: String?) {
            aliveEventSink?.success(AliveResult(2, msg, 0.0).toResult())
          }
        });
        result.success("alive_start_detect success")
      }
      else -> {
        result.notImplemented()
      }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel?.setMethodCallHandler(null)
  }
}
